@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '1.5005';
+our $VERSION = '1.5006';
 
 use Carp              ();
 use Fcntl             ();
@@ -149,7 +149,7 @@ sub new {
     my $options = $class->options;
     my $used    = 0;
     my $nargs   = scalar keys %args;
-    while(my $key = each %{$options}) {
+    foreach my $key(keys %{$options}) {
         if(exists $args{$key}) {
             $used++;
         }
@@ -202,8 +202,8 @@ sub new {
 
 sub _merge_hash {
     my($self, $base, $add) = @_;
-    while(my($name, $body) = each %{$add}) {
-        $base->{$name} = $body;
+    foreach my $name(keys %{$add}) {
+        $base->{$name} = $add->{$name};
     }
     return;
 }
@@ -583,7 +583,7 @@ Text::Xslate - Scalable template engine for Perl5
 
 =head1 VERSION
 
-This document describes Text::Xslate version 1.5005.
+This document describes Text::Xslate version 1.5006.
 
 =head1 SYNOPSIS
 
@@ -743,12 +743,12 @@ For example:
 
     # for bridge modules
     my $tx = Text::Xslate->new(
-        module => ['SomeModule::Bridge::Xslate'],
+        module => ['Text::Xslate::Bridge::Star'],
     );
     print $tx->render_string(
-        '<: $x.some_method() :>',
-        { x => time() },
-    );
+        '<: uc($x) :>',
+        { x => 'foo' },
+    ); # => 'FOO'
 
 Because you can use function-based modules with the C<module> option, and
 also can invoke any object methods in templates, Xslate doesn't require
@@ -1082,7 +1082,7 @@ An "too-safe" HTML escaping filter which escape all the symbolic characters
 
 =cut
 
-=head1 SUPPORT
+=head1 RESOURCES
 
 WEB: L<http://xslate.org/>
 
@@ -1090,9 +1090,9 @@ ML: L<http://groups.google.com/group/xslate>
 
 IRC: #xslate @ irc.perl.org
 
-REPOSITORY:
-    http://github.com/gfx/p5-Text-Xslate/
-    git://github.com/gfx/p5-Text-Xslate.git
+PROJECT HOME: L<http://github.com/xslate/>
+
+REPOSITORY: L<http://github.com/xslate/p5-Text-Xslate/>
 
 =head1 BUGS
 
